Renamed 'set_default_options()' to 'initialize_options()', and
'set_final_options()' to 'finalize_options()'.
diff --git a/Lib/distutils/command/build.py b/Lib/distutils/command/build.py
index d46132f..28241e1 100644
--- a/Lib/distutils/command/build.py
+++ b/Lib/distutils/command/build.py
@@ -25,7 +25,7 @@
          "compile extensions and libraries with debugging information"),
         ]
 
-    def set_default_options (self):
+    def initialize_options (self):
         self.build_base = 'build'
         # these are decided only after 'build_base' has its final value
         # (unless overridden by the user or client)
@@ -33,7 +33,7 @@
         self.build_platlib = None
         self.debug = None
 
-    def set_final_options (self):
+    def finalize_options (self):
         # 'build_lib' and 'build_platlib' just default to 'lib' and
         # 'platlib' under the base build directory
         if self.build_lib is None:
diff --git a/Lib/distutils/command/build_clib.py b/Lib/distutils/command/build_clib.py
index 26b89b3..9cf53da 100644
--- a/Lib/distutils/command/build_clib.py
+++ b/Lib/distutils/command/build_clib.py
@@ -33,7 +33,7 @@
          "compile with debugging information"),
         ]
 
-    def set_default_options (self):
+    def initialize_options (self):
         # List of libraries to build
         self.libraries = None
 
@@ -43,9 +43,9 @@
         self.undef = None
         self.debug = None
 
-    # set_default_options()
+    # initialize_options()
 
-    def set_final_options (self):
+    def finalize_options (self):
         self.set_undefined_options ('build',
                                     ('debug', 'debug'))
         self.libraries = self.distribution.libraries
@@ -58,7 +58,7 @@
         # XXX same as for build_ext -- what about 'self.define' and
         # 'self.undef' ?
 
-    # set_final_options()
+    # finalize_options()
 
 
     def run (self):
diff --git a/Lib/distutils/command/build_lib.py b/Lib/distutils/command/build_lib.py
index 26b89b3..9cf53da 100644
--- a/Lib/distutils/command/build_lib.py
+++ b/Lib/distutils/command/build_lib.py
@@ -33,7 +33,7 @@
          "compile with debugging information"),
         ]
 
-    def set_default_options (self):
+    def initialize_options (self):
         # List of libraries to build
         self.libraries = None
 
@@ -43,9 +43,9 @@
         self.undef = None
         self.debug = None
 
-    # set_default_options()
+    # initialize_options()
 
-    def set_final_options (self):
+    def finalize_options (self):
         self.set_undefined_options ('build',
                                     ('debug', 'debug'))
         self.libraries = self.distribution.libraries
@@ -58,7 +58,7 @@
         # XXX same as for build_ext -- what about 'self.define' and
         # 'self.undef' ?
 
-    # set_final_options()
+    # finalize_options()
 
 
     def run (self):
diff --git a/Lib/distutils/command/build_py.py b/Lib/distutils/command/build_py.py
index eecf88b..7ae207b 100644
--- a/Lib/distutils/command/build_py.py
+++ b/Lib/distutils/command/build_py.py
@@ -23,13 +23,13 @@
         ]
 
 
-    def set_default_options (self):
+    def initialize_options (self):
         self.build_dir = None
         self.modules = None
         self.package = None
         self.package_dir = None
 
-    def set_final_options (self):
+    def finalize_options (self):
         self.set_undefined_options ('build',
                                     ('build_lib', 'build_dir'))
 
diff --git a/Lib/distutils/command/install.py b/Lib/distutils/command/install.py
index 798460b..ffd6879 100644
--- a/Lib/distutils/command/install.py
+++ b/Lib/distutils/command/install.py
@@ -55,7 +55,7 @@
         ]
 
 
-    def set_default_options (self):
+    def initialize_options (self):
 
         self.build_base = None
         self.build_lib = None
@@ -89,7 +89,7 @@
         self.optimize_py = 1
 
 
-    def set_final_options (self):
+    def finalize_options (self):
 
         # XXX this method is where the default installation directories
         # for modules and extension modules are determined.  (Someday,
@@ -237,7 +237,7 @@
         # Punt on doc directories for now -- after all, we're punting on
         # documentation completely!
 
-    # set_final_options ()
+    # finalize_options ()
 
 
     def replace_sys_prefix (self, config_attr, fallback_postfix, use_exec=0):
diff --git a/Lib/distutils/command/install_ext.py b/Lib/distutils/command/install_ext.py
index 016a514..b046dfb 100644
--- a/Lib/distutils/command/install_ext.py
+++ b/Lib/distutils/command/install_ext.py
@@ -18,12 +18,12 @@
         ('build-dir=','b', "build directory (where to install from)"),
         ]
 
-    def set_default_options (self):
+    def initialize_options (self):
         # let the 'install' command dictate our installation directory
         self.install_dir = None
         self.build_dir = None
 
-    def set_final_options (self):
+    def finalize_options (self):
         self.set_undefined_options ('install',
                                     ('build_platlib', 'build_dir'),
                                     ('install_site_platlib', 'install_dir'))
diff --git a/Lib/distutils/command/install_lib.py b/Lib/distutils/command/install_lib.py
index 6dfebfb..919873c 100644
--- a/Lib/distutils/command/install_lib.py
+++ b/Lib/distutils/command/install_lib.py
@@ -18,14 +18,14 @@
         ]
                
 
-    def set_default_options (self):
+    def initialize_options (self):
         # let the 'install' command dictate our installation directory
         self.install_dir = None
         self.build_dir = None
         self.compile = 1
         self.optimize = 1
 
-    def set_final_options (self):
+    def finalize_options (self):
 
         # Find out from the 'build_ext' command if we were asked to build
         # any extensions.  If so, that means even pure-Python modules in
diff --git a/Lib/distutils/command/install_py.py b/Lib/distutils/command/install_py.py
index 6dfebfb..919873c 100644
--- a/Lib/distutils/command/install_py.py
+++ b/Lib/distutils/command/install_py.py
@@ -18,14 +18,14 @@
         ]
                
 
-    def set_default_options (self):
+    def initialize_options (self):
         # let the 'install' command dictate our installation directory
         self.install_dir = None
         self.build_dir = None
         self.compile = 1
         self.optimize = 1
 
-    def set_final_options (self):
+    def finalize_options (self):
 
         # Find out from the 'build_ext' command if we were asked to build
         # any extensions.  If so, that means even pure-Python modules in
diff --git a/Lib/distutils/command/sdist.py b/Lib/distutils/command/sdist.py
index aaedb30..042b1fc 100644
--- a/Lib/distutils/command/sdist.py
+++ b/Lib/distutils/command/sdist.py
@@ -50,7 +50,7 @@
     exclude_re = re.compile (r'\s*!\s*(\S+)') # for manifest lines
 
 
-    def set_default_options (self):
+    def initialize_options (self):
         # 'template' and 'manifest' are, respectively, the names of
         # the manifest template and manifest file.
         self.template = None
@@ -68,7 +68,7 @@
         self.keep_tree = 0
 
 
-    def set_final_options (self):
+    def finalize_options (self):
         if self.manifest is None:
             self.manifest = "MANIFEST"
         if self.template is None:
diff --git a/Lib/distutils/command/build_ext.py b/Lib/distutils/command/build_ext.py
index 963abc2..8ed3a97 100644
--- a/Lib/distutils/command/build_ext.py
+++ b/Lib/distutils/command/build_ext.py
@@ -38,9 +38,9 @@
     #     structure
     #   - that data structure (in this case, a list of 2-tuples)
     #     will then be present in the command object by the time
     #     we get to set_final_options() (i.e. the constructor
     #     takes care of both command-line and client options
-    #     in between set_default_options() and set_final_options())
+    #     in between initialize_options() and finalize_options())
 
     user_options = [
         ('build-dir=', 'd',
@@ -64,7 +64,7 @@
         ]
 
 
-    def set_default_options (self):
+    def initialize_options (self):
         self.extensions = None
         self.build_dir = None
         self.package = None
@@ -79,7 +79,7 @@
         self.debug = None
 
 
-    def set_final_options (self):
+    def finalize_options (self):
         from distutils import sysconfig
 
         self.set_undefined_options ('build',
@@ -112,7 +112,7 @@
         # XXX how the heck are 'self.define' and 'self.undef' supposed to
         # be set?
 
-    # set_final_options ()
+    # finalize_options ()
     
 
     def run (self):
@@ -38,9 +38,9 @@
     #   - that data structure (in this case, a list of 2-tuples)
     #     will then be present in the command object by the time
-    #     we get to set_final_options() (i.e. the constructor
+    #     we get to finalize_options() (i.e. the constructor
     #     takes care of both command-line and client options